#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `pyatlonajuno` package."""

import pytest
from unittest.mock import MagicMock, Mock

from click.testing import CliRunner

from pyatlonajuno import lib
from pyatlonajuno import cli


@pytest.fixture
def j451():
    j = lib.Juno451("url")
    j.requests = MagicMock()
    j.requests.get = MagicMock()
    return j


def test_getPowerState(j451):
    j451.getPowerState()
    j451.requests.get.assert_called_with('url/aj.html?a=sys')


def test_setPowerState(j451):
    j451.setPowerState("on")
    j451.requests.get.assert_called_with('url/aj.html?a=command&cmd=PWON')


def test_getSource(j451):
    j451.getSource()
    j451.requests.get.assert_called_with('url/aj.html?a=avs')


def test_setSource(j451):
    j451.setSource(1)
    j451.requests.get.assert_called_with('url/aj.html?a=command&cmd=x1AVx1')


def test_command_line_interface():
    """Test the CLI."""
    runner = CliRunner()
    result = runner.invoke(cli.cli)
    assert result.exit_code == 0
    #assert 'pyatlonajuno.cli.main' in result.output
    help_result = runner.invoke(cli.cli, ['--help'])
    assert help_result.exit_code == 0
    assert 'Show this message and exit.' in help_result.output



import requests

# x${input}AVx1
# curl -v "http://hdmi/aj.html?a=command&cmd=x1AVx1"
# curl -v "http://hdmi/aj.html?a=command&cmd=PWON"

# curl -va "http://hdmi/aj.html?a=avs"
# {"login_ur":1,"inp":1,"asw":0,"HDMIAud":1,"ARC":0,"Toslink":1,"HDCPSet":[1,1,1,1]}

# curl -va "http://hdmi/aj.html?a=sys"
# {"login_ur":1,"tp":23,"tel_log":1,"ttimeout":120,"broad":1,"PW":1,"Lock_obj":0}


class Juno451IllegalArgumentException(Exception):
    pass


class Juno451:
    def __init__(self, url, debug=False, timeout=5):
        self.requests = requests
        self.url = url
        self.debug = debug
        self.timeout = int(timeout)  # seconds

    def getPowerState(self):
        """returns on or off"""
        if self.requests.get(self.url+"/aj.html?a=sys").json()['PW'] == 1:
            return "on"
        else:
            return "off"

    def setPowerState(self, state):
        if state == "on":
            self.requests.get(self.url+"/aj.html?a=command&cmd=PWON")
        elif state == "off":
            self.requests.get(self.url+"/aj.html?a=command&cmd=PWOFF")
        else:
            raise Juno451IllegalArgumentException(
                "Invalid power state: {state}, should be on or off."
                .format(state=state))

    def getSource(self):
        return self.requests.get(self.url+"/aj.html?a=avs").json()['inp']

    def getSignalDetected(self):
        """ Returns true if signal is detected AND power is on """
        return self.requests.get(self.url+"/aj.html?a=info").json()['info_val2'][2] != "No Signal"

    def setSource(self, source):
        if int(source) not in range(1, 5):
            raise Juno451IllegalArgumentException(
                "Source: {source} not valid, must be 1,2,3 or 4"
                .format(source=source))
        self.requests.get(
            self.url+"/aj.html?a=command&cmd=x{}AVx1".format(source))




import click

from . import lib


@click.group()
@click.option("--url")
@click.option("--debug/--no-debug", default=False)
@click.option("--timeout", default=5, type=int,
              help="Seconds to wait for telnet responses")
@click.pass_context
def cli(ctx, url, debug, timeout):
    """ Juno451 CLI.

    This cli is for controling the Atlona Juno 451 HDMI switch.
    """
    ctx.obj = lib.Juno451(url, debug, timeout)


@cli.command()
@click.pass_context
def getpowerstate(ctx):
    "Determine if the Juno is currently powered up"
    print(ctx.obj.getPowerState())


@cli.command()
@click.option("--state", type=click.Choice(["on", "off"]), required=True)
@click.pass_context
def setpowerstate(ctx, state):
    "Turn the Juno on or off"
    print(ctx.obj.setPowerState(state))


@cli.command()
@click.pass_context
def getinputstate(ctx):
    "Get the connection status of the four inputs, True=connected"
    print(ctx.obj.getInputState())


@cli.command()
@click.pass_context
def getsource(ctx):
    "Get the currently active input"
    print(ctx.obj.getSource())


@cli.command()
@click.option("--source",
              type=click.Choice(["1", "2", "3", "4"]),
              required=True)
@click.pass_context
def setsource(ctx, source):
    "Select an input"
    print(ctx.obj.setSource(source))


def main():
    cli()


if __name__ == "__main__":
    cli()
